%define upstream_name    Prima
%define upstream_version 1.73

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 1

Summary:    Standard dialog
License:    GPL+ or Artistic
Group:      Development/Perl
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    https://cpan.metacpan.org/modules/by-module/Prima/%{upstream_name}-%{upstream_version}.tar.gz

BuildRequires: perl(ExtUtils::MakeMaker)
BuildRequires: freetype-devel
BuildRequires: giflib-devel
BuildRequires: pkgconfig(libjpeg)
BuildRequires: perl
BuildRequires: perl-devel
BuildRequires: pkgconfig(fontconfig)
BuildRequires: pkgconfig(gdk-2.0)
BuildRequires: pkgconfig(libpng)
BuildRequires: pkgconfig(libtiff-4)
BuildRequires: pkgconfig(x11)
BuildRequires: pkgconfig(xpm)
# Run-time:

# Virtual packages used to load more modules
Provides:   perl(Prima::Buttons) = %{version}
Provides:   perl(Prima::Classes) = %{version}
Provides:   perl(Prima::Notebooks) = %{version}
Provides:   perl(Prima::Outlines) = %{version}
Provides:   perl(Prima::Sliders) = %{version}
Provides:   perl(Prima::StdDlg) = %{version}
# Public modules without a package keyword:
Provides:   perl(Prima::noARGV) = %{version}
Provides:   perl(Prima::PS::Drawable::Path) = %{version}
Provides:   perl(Prima::PS::Drawable::Region) = %{version}
Provides:   perl(Prima::PS::Setup) = %{version}

%{?perl_default_filter}

# Do not export private modules (not starting with "Prima")
%global __provides_exclude %{?__provides_exclude:%__provides_exclude|}^perl\\((am|apc|bi|bs|bt|ci|cl|cm|CodeEditor|cr|cs|CustomPodView|Divider|dmfp|dt|Editor|fdo|fds|fe|fp|fr|fra|frr|fs|fw|gm|gr|grow|gsci|gt|gui|ict|im|is|ItemsOutline|kb|km|le|lj|lp|mb|mbi|MenuOutline|MPropListViewer|mt|MyOutline|nt|PackPropListViewer|PropListViewer|rop|Round3D|sbmp|ss|sv|ta|tb|tka|tm|tno|tns|tw|wc|ws)\\)

# Filter under-specified provides
%global __provides_exclude %{?__provides_exclude:%__provides_exclude|}^perl\\(Prima\\)$

%description
The toolkit is combined from two basic set of classes - core and external.
The core classes are coded in C and form a base line for every Prima object
written in perl. The usage of C is possible together with the toolkit;
however, its full power is revealed in the perl domain. The external
classes present easily expandable set of widgets, written completely in
perl and communicating with the system using Prima library calls.

The core classes form an hierarchy, which is displayed below:

	Prima::Object
		Prima::Component
			Prima::AbstractMenu
				Prima::AccelTable
				Prima::Menu
				Prima::Popup
			Prima::Clipboard
			Prima::Drawable
				Prima::DeviceBitmap
				Prima::Printer
				Prima::Image
					Prima::Icon
			Prima::File
			Prima::Timer
			Prima::Widget
				Prima::Application
				Prima::Window

%prep
%autosetup -p1 -n %{upstream_name}-%{upstream_version}

%build
%__perl Makefile.PL INSTALLDIRS=vendor

%make_build

%check
%make_build test||:

%install
%make_install

%files
%doc Changes LICENSE META.json META.yml MYMETA.yml examples
%{_bindir}/*
%{_mandir}/man*/*
%{perl_vendorarch}/*

%changelog
* Wed May 22 2024 tv <tv> 1.730.0-1.mga10
+ Revision: 2065994
- update to 1.73

* Thu Feb 01 2024 tv <tv> 1.720.0-1.mga10
+ Revision: 2036552
- update to 1.72

* Wed Nov 29 2023 tv <tv> 1.710.0-2.mga10
+ Revision: 2011266
- Rebuild for perl-5.38

* Wed Nov 01 2023 tv <tv> 1.710.0-1.mga10
+ Revision: 2003280
- update to 1.71

* Wed Sep 06 2023 tv <tv> 1.700.0-1.mga10
+ Revision: 1984803
- update to 1.70

* Wed Aug 30 2023 tv <tv> 1.690.0-1.mga10
+ Revision: 1981946
- update to 1.69

* Mon Feb 20 2023 tv <tv> 1.670.10-1.mga9
+ Revision: 1944268
- update to 1.67001

* Mon Dec 12 2022 ns80 <ns80> 1.670.0-2.mga9
+ Revision: 1921096
- rebuild for new libtiff

* Mon Dec 05 2022 tv <tv> 1.670.0-1.mga9
+ Revision: 1918169
- update to 1.67

* Sat Aug 27 2022 tv <tv> 1.660.0-1.mga9
+ Revision: 1881137
- update to 1.66

* Tue Jun 07 2022 umeabot <umeabot> 1.650.0-2.mga9
+ Revision: 1862315
- Rebuild for Perl 5.36

* Mon Apr 25 2022 tv <tv> 1.650.0-1.mga9
+ Revision: 1853138
- update to 1.65

* Tue Apr 12 2022 tv <tv> 1.640.0-1.mga9
+ Revision: 1849091
- update to 1.64

* Wed Mar 30 2022 umeabot <umeabot> 1.630.0-2.mga9
+ Revision: 1835619
- Mageia 9 Mass Rebuild

* Tue Sep 14 2021 tv <tv> 1.630.0-1.mga9
+ Revision: 1745438
- update to 1.63

* Wed Jun 23 2021 tv <tv> 1.620.0-1.mga9
+ Revision: 1731916
- update to 1.62

* Mon May 24 2021 umeabot <umeabot> 1.610.0-3.mga9
+ Revision: 1727040
- Rebuild for perl 5.34

* Tue May 18 2021 tv <tv> 1.610.0-2.mga9
+ Revision: 1725389
- Fix self deps

* Wed Apr 28 2021 tv <tv> 1.610.0-1.mga9
+ Revision: 1720250
- update to 1.61

* Wed Nov 11 2020 tv <tv> 1.600.0-2.mga8
+ Revision: 1644434
- fix deps

* Sun Nov 01 2020 tv <tv> 1.600.0-1.mga8
+ Revision: 1641076
- update to 1.60

* Wed Jun 17 2020 umeabot <umeabot> 1.590.0-2.mga8
+ Revision: 1595144
- Rebuild for perl 5.32

* Thu May 28 2020 tv <tv> 1.590.0-1.mga8
+ Revision: 1588347
- update to 1.59

* Mon Mar 16 2020 tv <tv> 1.580.0-1.mga8
+ Revision: 1556600
- update to 1.58

* Tue Feb 18 2020 umeabot <umeabot> 1.570.0-3.mga8
+ Revision: 1538291
- Mageia 8 Mass Rebuild

* Mon Nov 18 2019 tv <tv> 1.570.0-2.mga8
+ Revision: 1461603
- update to 1.57

* Tue Aug 27 2019 tmb <tmb> 1.560.0-2.mga8
+ Revision: 1433880
- rebuild for perl 5.30

* Sun Aug 25 2019 tv <tv> 1.560.0-1.mga8
+ Revision: 1432104
- update to 1.56

* Mon Mar 25 2019 tv <tv> 1.550.0-1.mga7
+ Revision: 1380186
- update to 1.55

* Sun Feb 03 2019 tv <tv> 1.540.0-1.mga7
+ Revision: 1362877
- update to 1.54

* Sat Oct 20 2018 tv <tv> 1.530.0-1.mga7
+ Revision: 1322735
- update to 1.53

* Fri Sep 21 2018 umeabot <umeabot> 1.520.0-5.mga7
+ Revision: 1293659
- Mageia 7 Mass Rebuild

* Sat Aug 25 2018 tv <tv> 1.520.0-4.mga7
+ Revision: 1253902
- remove no more needed requires exclude
- fix deps

* Wed Aug 08 2018 pterjan <pterjan> 1.520.0-3.mga7
+ Revision: 1250336
- Rebuild for perl 5.28

* Tue Oct 03 2017 tv <tv> 1.520.0-2.mga7
+ Revision: 1166377
- rebuild with fixed rpm for missing autodeps

* Sun Sep 24 2017 sander85 <sander85> 1.520.0-1.mga7
+ Revision: 1158497
- update to 1.52

* Thu Aug 31 2017 pterjan <pterjan> 1.460.0-4.mga7
+ Revision: 1149918
- Rebuild for perl ABI changes

* Sat Jul 22 2017 neoclust <neoclust> 1.460.0-3.mga7
+ Revision: 1126737
- Rebuild against new Perl 5.26

* Sun Jun 19 2016 pterjan <pterjan> 1.460.0-2.mga6
+ Revision: 1032693
- Rebuild for perl 5.22.2

* Mon May 02 2016 tv <tv> 1.460.0-1.mga6
+ Revision: 1008655
- new release

* Sat Feb 20 2016 tv <tv> 1.450.0-1.mga6
+ Revision: 972439
- drop merged patches
- new release

* Fri Feb 12 2016 umeabot <umeabot> 1.440.0-2.mga6
+ Revision: 957890
- Mageia 6 Mass Rebuild

* Wed Aug 05 2015 sander85 <sander85> 1.440.0-1.mga6
+ Revision: 861386
- update to 1.44

* Fri Jun 26 2015 tv <tv> 1.430.0-3.mga6
+ Revision: 845158
- rebuild for soname-ifed perl

* Wed Jun 24 2015 shlomif <shlomif> 1.430.0-2.mga6
+ Revision: 842000
- Add a requires_exclude

* Wed Jun 24 2015 sander85 <sander85> 1.430.0-1.mga6
+ Revision: 841775
- update to 1.43

* Wed Oct 15 2014 umeabot <umeabot> 1.400.0-3.mga5
+ Revision: 749861
- Second Mageia 5 Mass Rebuild

* Fri Oct 03 2014 tv <tv> 1.400.0-2.mga5
+ Revision: 736585
- drop bogus requires

* Fri Oct 03 2014 tv <tv> 1.400.0-1.mga5
+ Revision: 736354
- add more BR
- imported package perl-Prima

